@@ -20,6 +20,7 @@
 #include <QJsonParseError>
 #include "BrowserAction.h"
 #include "BrowserSettings.h"
+#include "NativeMessagingBase.h"
 #include "sodium.h"
 #include "sodium/crypto_box.h"
 #include "sodium/randombytes.h"
@@ -168,7 +169,9 @@ QJsonObject BrowserAction::handleAssociate(const QJsonObject& json, const QStrin
 
     QMutexLocker locker(&m_mutex);
     if (key.compare(m_clientPublicKey, Qt::CaseSensitive) == 0) {
-        const QString id = m_browserService.storeKey(key);
+        // Check for identification key. If it's not found, ensure backwards compatibility and use the current public key
+        const QString idKey = decrypted.value("idKey").toString();
+        const QString id = m_browserService.storeKey((idKey.isEmpty() ? key: idKey));
         if (id.isEmpty()) {
             return getErrorReply(action, ERROR_KEEPASS_ACTION_CANCELLED_OR_DENIED);
         }
@@ -239,9 +242,17 @@ QJsonObject BrowserAction::handleGetLogins(const QJsonObject& json, const QStrin
         return getErrorReply(action, ERROR_KEEPASS_NO_URL_PROVIDED);
     }
 
+    const QJsonArray keys = decrypted.value("keys").toArray();
+
+    StringPairList keyList;
+    for (const QJsonValue val : keys) {
+        const QJsonObject keyObject = val.toObject();
+        keyList.push_back(qMakePair(keyObject.value("id").toString(), keyObject.value("key").toString()));
+    }
+
     const QString id = decrypted.value("id").toString();
     const QString submit = decrypted.value("submitUrl").toString();
-    const QJsonArray users = m_browserService.findMatchingEntries(id, url, submit, "");
+    const QJsonArray users = m_browserService.findMatchingEntries(id, url, submit, "", keyList);
 
     if (users.isEmpty()) {
         return getErrorReply(action, ERROR_KEEPASS_NO_LOGINS_FOUND);
@@ -456,7 +467,7 @@ QString BrowserAction::encrypt(const QString plaintext, const QString nonce)
     std::vector<unsigned char> sk(sa.cbegin(), sa.cend());
 
     std::vector<unsigned char> e;
-    e.resize(max_length);
+    e.resize(NATIVE_MSG_MAX_LENGTH);
 
     if (m.empty() || n.empty() || ck.empty() || sk.empty()) {
         return QString();
@@ -484,7 +495,7 @@ QByteArray BrowserAction::decrypt(const QString encrypted, const QString nonce)
     std::vector<unsigned char> sk(sa.cbegin(), sa.cend());
 
     std::vector<unsigned char> d;
-    d.resize(max_length);
+    d.resize(NATIVE_MSG_MAX_LENGTH);
 
     if (m.empty() || n.empty() || ck.empty() || sk.empty()) {
         return QByteArray();
