@@ -633,25 +633,22 @@ void DatabaseWidget::openUrl()
 
 void DatabaseWidget::openUrlForEntry(Entry* entry)
 {
-    QString urlString = entry->resolveMultiplePlaceholders(entry->url());
-    if (urlString.isEmpty()) {
-        return;
-    }
-
-    if (urlString.startsWith("cmd://")) {
+    QString cmdString = entry->resolveMultiplePlaceholders(entry->url());
+    if (cmdString.startsWith("cmd://")) {
         // check if decision to execute command was stored
         if (entry->attributes()->hasKey(EntryAttributes::RememberCmdExecAttr)) {
             if (entry->attributes()->value(EntryAttributes::RememberCmdExecAttr) == "1") {
-                QProcess::startDetached(urlString.mid(6));
+                QProcess::startDetached(cmdString.mid(6));
             }
             return;
         }
 
         // otherwise ask user
-        if (urlString.length() > 6) {
-            QString cmdTruncated = urlString.mid(6);
-            if (cmdTruncated.length() > 400)
+        if (cmdString.length() > 6) {
+            QString cmdTruncated = cmdString.mid(6);
+            if (cmdTruncated.length() > 400) {
                 cmdTruncated = cmdTruncated.left(400) + " […]";
+            }
             QMessageBox msgbox(QMessageBox::Icon::Question,
                                tr("Execute command?"),
                                tr("Do you really want to execute the following command?<br><br>%1<br>")
@@ -672,7 +669,7 @@ void DatabaseWidget::openUrlForEntry(Entry* entry)
 
             int result = msgbox.exec();
             if (result == QMessageBox::Yes) {
-                QProcess::startDetached(urlString.mid(6));
+                QProcess::startDetached(cmdString.mid(6));
             }
 
             if (remember) {
@@ -680,10 +677,11 @@ void DatabaseWidget::openUrlForEntry(Entry* entry)
                                          result == QMessageBox::Yes ? "1" : "0");
             }
         }
-    }
-    else {
-        QUrl url = QUrl::fromUserInput(urlString);
-        QDesktopServices::openUrl(url);
+    } else {
+        QString urlString = entry->webUrl();
+        if (!urlString.isEmpty()) {
+            QDesktopServices::openUrl(urlString);
+        }
     }
 }
 
