@@ -23,6 +23,7 @@
 #include <QMimeData>
 #include <QShortcut>
 #include <QTimer>
+#include <QDesktopServices>
 
 #include "config-keepassx.h"
 
@@ -117,7 +118,7 @@ class BrowserPlugin: public ISettingsPage
 {
     public:
         BrowserPlugin(DatabaseTabWidget* tabWidget) {
-            m_nativeMessagingHost = QSharedPointer<NativeMessagingHost>(new NativeMessagingHost(tabWidget));
+            m_nativeMessagingHost = QSharedPointer<NativeMessagingHost>(new NativeMessagingHost(tabWidget, BrowserSettings::isEnabled()));
         }
 
         ~BrowserPlugin() {
@@ -389,7 +390,7 @@ MainWindow::MainWindow()
     m_actionMultiplexer.connect(m_ui->actionGroupEmptyRecycleBin, SIGNAL(triggered()),
             SLOT(emptyRecycleBin()));
 
-    connect(m_ui->actionSettings, SIGNAL(triggered()), SLOT(switchToSettings()));
+    connect(m_ui->actionSettings, SIGNAL(toggled(bool)), SLOT(switchToSettings(bool)));
     connect(m_ui->actionPasswordGenerator, SIGNAL(toggled(bool)), SLOT(switchToPasswordGen(bool)));
     connect(m_ui->passwordGeneratorWidget, SIGNAL(dialogTerminated()), SLOT(closePasswordGen()));
 
@@ -400,6 +401,8 @@ MainWindow::MainWindow()
     connect(m_ui->welcomeWidget, SIGNAL(importCsv()), SLOT(switchToImportCsv()));
 
     connect(m_ui->actionAbout, SIGNAL(triggered()), SLOT(showAboutDialog()));
+    connect(m_ui->actionDonate, SIGNAL(triggered()), SLOT(openDonateUrl()));
+    connect(m_ui->actionBugReport, SIGNAL(triggered()), SLOT(openBugReportUrl()));
 
 #ifdef Q_OS_MAC
     setUnifiedTitleAndToolBarOnMac(true);
@@ -426,11 +429,18 @@ MainWindow::MainWindow()
     }
 #endif
 
-#ifndef KEEPASSXC_BUILD_TYPE_RELEASE
+#if !defined(KEEPASSXC_BUILD_TYPE_RELEASE)
     m_ui->globalMessageWidget->showMessage(tr("WARNING: You are using an unstable build of KeePassXC!\n"
                                               "There is a high risk of corruption, maintain a backup of your databases.\n"
                                               "This version is not meant for production use."),
-                                           MessageWidget::Warning, -1);
+                                          MessageWidget::Warning, -1);
+#elif (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0) && QT_VERSION < QT_VERSION_CHECK(5, 6, 0))
+    if (!config()->get("QtErrorMessageShown", false).toBool()) {
+        m_ui->globalMessageWidget->showMessage(tr("WARNING: Your Qt version may cause KeePassXC to crash with an On-Screen Keyboard!\n"
+                                                  "We recommend you use the AppImage available on our downloads page."),
+                                              MessageWidget::Warning, -1);
+        config()->set("QtErrorMessageShown", true);
+    }
 #else
     // Show the HTTP deprecation message if enabled above
     emit m_ui->globalMessageWidget->hideAnimationFinished();
@@ -647,7 +657,6 @@ void MainWindow::setMenuActionState(DatabaseWidget::Mode mode)
     m_ui->actionDatabaseOpen->setEnabled(inDatabaseTabWidgetOrWelcomeWidget);
     m_ui->menuRecentDatabases->setEnabled(inDatabaseTabWidgetOrWelcomeWidget);
     m_ui->menuImport->setEnabled(inDatabaseTabWidgetOrWelcomeWidget);
-    m_ui->actionDatabaseMerge->setEnabled(inDatabaseTabWidget);
     m_ui->actionRepairDatabase->setEnabled(inDatabaseTabWidgetOrWelcomeWidget);
 
     m_ui->actionLockDatabases->setEnabled(m_ui->tabWidget->hasLockableDatabases());
@@ -656,6 +665,10 @@ void MainWindow::setMenuActionState(DatabaseWidget::Mode mode)
         bool blocked = m_ui->actionPasswordGenerator->blockSignals(true);
         m_ui->actionPasswordGenerator->toggle();
         m_ui->actionPasswordGenerator->blockSignals(blocked);
+    } else if ((currentIndex == SettingsScreen) != m_ui->actionSettings->isChecked()) {
+        bool blocked = m_ui->actionSettings->blockSignals(true);
+        m_ui->actionSettings->toggle();
+        m_ui->actionSettings->blockSignals(blocked);
     }
 }
 
@@ -704,6 +717,16 @@ void MainWindow::showAboutDialog()
     aboutDialog->open();
 }
 
+void MainWindow::openDonateUrl()
+{
+    QDesktopServices::openUrl(QUrl("https://keepassxc.org/donate"));
+}
+
+void MainWindow::openBugReportUrl()
+{
+    QDesktopServices::openUrl(QUrl("https://github.com/keepassxreboot/keepassxc/issues"));
+}
+
 void MainWindow::switchToDatabases()
 {
     if (m_ui->tabWidget->currentIndex() == -1) {
@@ -714,15 +737,19 @@ void MainWindow::switchToDatabases()
     }
 }
 
-void MainWindow::switchToSettings()
+void MainWindow::switchToSettings(bool enabled)
 {
-    m_ui->settingsWidget->loadSettings();
-    m_ui->stackedWidget->setCurrentIndex(SettingsScreen);
+    if (enabled) {
+        m_ui->settingsWidget->loadSettings();
+        m_ui->stackedWidget->setCurrentIndex(SettingsScreen);
+    } else {
+        switchToDatabases();
+    }
 }
 
 void MainWindow::switchToPasswordGen(bool enabled)
 {
-    if (enabled == true) {
+    if (enabled) {
       m_ui->passwordGeneratorWidget->loadSettings();
       m_ui->passwordGeneratorWidget->regeneratePassword();
       m_ui->passwordGeneratorWidget->setStandaloneMode(true);
@@ -797,7 +824,7 @@ void MainWindow::closeEvent(QCloseEvent* event)
                            config()->get("GUI/MinimizeOnClose").toBool();
     if (minimizeOnClose && !m_appExitCalled)
     {
-        event->ignore();
+        event->accept();
         hideWindow();
 
         if (config()->get("security/lockdatabaseminimize").toBool()) {
@@ -899,7 +926,7 @@ void MainWindow::updateTrayIcon()
 
             m_trayIcon->setContextMenu(menu);
             
-            m_trayIcon->setIcon(filePath()->applicationIcon());
+            m_trayIcon->setIcon(filePath()->trayIcon());
             m_trayIcon->show();
         }
         if (m_ui->tabWidget->hasLockableDatabases()) {
@@ -971,7 +998,11 @@ void MainWindow::trayIconTriggered(QSystemTrayIcon::ActivationReason reason)
 void MainWindow::hideWindow()
 {
     saveWindowInformation();
-#ifndef Q_OS_MAC
+#if !defined(Q_OS_LINUX) && !defined(Q_OS_MAC)
+    // On some Linux systems, the window should NOT be minimized and hidden (i.e. not shown), at
+    // the same time (which would happen if both minimize on startup and minimize to tray are set)
+    // since otherwise it causes problems on restore as seen on issue #1595. Hiding it is enough.
+    // TODO: Add an explanation for why this is also not done on Mac (or remove the check)
     setWindowState(windowState() | Qt::WindowMinimized);
 #endif
     QTimer::singleShot(0, this, SLOT(hide()));
@@ -983,7 +1014,7 @@ void MainWindow::hideWindow()
 
 void MainWindow::toggleWindow()
 {
-    if ((QApplication::activeWindow() == this) && isVisible() && !isMinimized()) {
+    if (isVisible() && !isMinimized()) {
         hideWindow();
     } else {
         bringToFront();
