@@ -71,6 +71,8 @@ void TestGui::initTestCase()
     Config::createTempFileInstance();
     // Disable autosave so we can test the modified file indicator
     Config::instance()->set("AutoSaveAfterEveryChange", false);
+    // Enable the tray icon so we can test hiding/restoring the window
+    Config::instance()->set("GUI/ShowTrayIcon", true);
 
     m_mainWindow = new MainWindow();
     m_tabWidget = m_mainWindow->findChild<DatabaseTabWidget*>("tabWidget");
@@ -475,6 +477,9 @@ void TestGui::testAddEntry()
     QTest::keyClicks(passwordRepeatEdit, "something 2");
     QTest::mouseClick(editEntryWidgetButtonBox->button(QDialogButtonBox::Ok), Qt::LeftButton);
 
+/* All apply tests disabled due to data loss workaround
+ * that disables apply button on new entry creation
+ *
     // Add entry "something 3" using the apply button then click ok
     QTest::mouseClick(entryNewWidget, Qt::LeftButton);
     QTest::keyClicks(titleEdit, "something 3");
@@ -486,6 +491,7 @@ void TestGui::testAddEntry()
     QTest::keyClicks(titleEdit, "something 4");
     QTest::mouseClick(editEntryWidgetButtonBox->button(QDialogButtonBox::Apply), Qt::LeftButton);
     QTest::mouseClick(editEntryWidgetButtonBox->button(QDialogButtonBox::Cancel), Qt::LeftButton);
+*/
 
     // Add entry "something 5" but click cancel button (does NOT add entry)
     QTest::mouseClick(entryNewWidget, Qt::LeftButton);
@@ -494,8 +500,8 @@ void TestGui::testAddEntry()
 
     QApplication::processEvents();
 
-    // Confirm that 5 entries now exist
-    QTRY_COMPARE(entryView->model()->rowCount(), 5);
+    // Confirm entry count
+    QTRY_COMPARE(entryView->model()->rowCount(), 3);
 }
 
 void TestGui::testPasswordEntryEntropy()
@@ -1091,6 +1097,32 @@ void TestGui::testDragAndDropKdbxFiles()
     QCOMPARE(m_tabWidget->count(), openedDatabasesCount);
 }
 
+void TestGui::testTrayRestoreHide()
+{
+    if (!QSystemTrayIcon::isSystemTrayAvailable()) {
+        QSKIP("QSystemTrayIcon::isSystemTrayAvailable() = false, skipping tray restore/hide test...");
+    }
+
+    QSystemTrayIcon* trayIcon = m_mainWindow->findChild<QSystemTrayIcon*>();
+    QVERIFY(m_mainWindow->isVisible());
+
+    trayIcon->activated(QSystemTrayIcon::Trigger);
+    Tools::wait(100);
+    QVERIFY(!m_mainWindow->isVisible());
+
+    trayIcon->activated(QSystemTrayIcon::Trigger);
+    Tools::wait(100);
+    QVERIFY(m_mainWindow->isVisible());
+
+    trayIcon->activated(QSystemTrayIcon::Trigger);
+    Tools::wait(100);
+    QVERIFY(!m_mainWindow->isVisible());
+
+    trayIcon->activated(QSystemTrayIcon::Trigger);
+    Tools::wait(100);
+    QVERIFY(m_mainWindow->isVisible());
+}
+
 void TestGui::cleanupTestCase()
 {
     delete m_mainWindow;
